AutoRoleCheck = {};

AutoRoleCheck.Defaults = {
   Enabled = true,
   DisableOnce = false,
   Comment = ""
};

SLASH_AUTOROLECHECK1, SLASH_AUTOROLECHECK2 = "/arc", "/autorolecheck";

local frame = CreateFrame("FRAME");
frame:RegisterEvent("ADDON_LOADED");
frame:RegisterEvent("PLAYER_LOGOUT");
frame:RegisterEvent("PLAYER_FLAGS_CHANGED");

function AutoRoleCheck.ShowMessage(text)
   print("|cff90ff90ARC:|r " .. text);
end

function SlashCmdList.AUTOROLECHECK(msg, editbox)
   local command, rest = msg:match("^(%S*)%s*(.-)$");
   command = command:lower();

   if ( command == "enable" ) then
      AutoRoleCheck.PrevStatus = nil;
      AutoRoleCheck.Options.DisableOnce = false;
      AutoRoleCheck.Options.Enabled = true;
      AutoRoleCheck.ShowMessage("Enabled");
   elseif ( command == "disable" ) then
      AutoRoleCheck.PrevStatus = nil;
      AutoRoleCheck.DisableOnce = false;
      AutoRoleCheck.Options.Enabled = false;
      AutoRoleCheck.ShowMessage("Disabled");
   elseif ( command == "disableonce" ) then
      AutoRoleCheck.PrevStatus = nil;
      AutoRoleCheck.Options.DisableOnce = true;
      AutoRoleCheck.Options.Enabled = false;
      AutoRoleCheck.ShowMessage("Disabled for next role check only.");
   elseif ( command == "comment" ) then
      if ( rest == "clear" ) then
         AutoRoleCheck.Options.Comment = "";
         AutoRoleCheck.ShowMessage("Comment cleared");
         return
      elseif ( rest ~= "" ) then
         AutoRoleCheck.Options.Comment = rest;
      end
      AutoRoleCheck.ShowMessage("Comment set to " .. AutoRoleCheck.Options.Comment);
   else
      AutoRoleCheck.ShowMessage("Available commands:");
      print("  /arc enable - enable addon");
      print("  /arc disable - disable addon");
      print("  /arc disableonce - disable only for the next role check");
      print("  /arc comment [msg | clear] - view, set or clear comment");
   end
end

local function RestorePrevStatus()
   AutoRoleCheck.Options.Enabled = AutoRoleCheck.PrevStatus;
   AutoRoleCheck.PrevStatus = nil;
end

local function EventHandler(self, event, arg, ...)
   if ( event == "ADDON_LOADED" and arg == "autorolecheck" ) then
      AutoRoleCheck.ShowMessage("type /arc or /autorolecheck for options.");

      -- merge saved options with defaults
      AutoRoleCheck.Options = AutoRoleCheck.Defaults;
      if ( AutoRoleCheck_Options ) then
         for k, v in pairs(AutoRoleCheck_Options) do
            AutoRoleCheck.Options[k] = v;
         end
      end
   elseif ( event == "PLAYER_FLAGS_CHANGED" and arg == "player" ) then
      local isAFK, isDND = UnitIsAFK(arg), UnitIsDND(arg);
      if ( isAFK or isDND ) then
         if ( not AutoRoleCheck.PrevStatus ) then
            AutoRoleCheck.PrevStatus = AutoRoleCheck.Options.Enabled;
         end
         AutoRoleCheck.Options.Enabled = false;
      elseif ( AutoRoleCheck.PrevStatus ~= nil ) then
         RestorePrevStatus();
      end
   elseif ( event == "PLAYER_LOGOUT" ) then
      if ( AutoRoleCheck.PrevStatus ~= nil ) then
         RestorePrevStatus();
      end
      AutoRoleCheck_Options = AutoRoleCheck.Options;
   end
end

frame:SetScript("OnEvent", EventHandler);
